#
# spec file for package the_silver_searcher
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           the_silver_searcher
Version:        2.2.0
Release:        4.3
Summary:        A code-searching tool similar to ack, but faster
License:        Apache-2.0
Group:          Productivity/File utilities
URL:            https://github.com/ggreer/the_silver_searcher
Source:         http://geoff.greer.fm/ag/releases/%{name}-%{version}.tar.gz
Source2:        http://geoff.greer.fm/ag/releases/%{name}-%{version}.tar.gz.asc
Source3:        %{name}.keyring
Source4:        %{name}.changes
# PATCH-FIX-UPSTREAM the_silver_searcher-2.2.0-portabilityfixes.patch gh#ggreer/the_silver_searcher#1377 -- Fix multiple global symbols definitions
Patch0:         the_silver_searcher-2.2.0-portabilityfixes.patch
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(zlib)

%description
A code searching tool similar to ack, with a focus on speed.

%prep
%autosetup -p1

%build
%configure
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}/%{_datadir}/bash-completion/completions/
mv -v %{buildroot}%{_datadir}/%{name}/completions/ag.bashcomp.sh %{buildroot}/%{_datadir}/bash-completion/completions/%{name}

%files
%license LICENSE
%doc NOTICE README.md
%{_bindir}/ag
%{_mandir}/man1/ag.1%{?ext_man}
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_the_silver_searcher

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Remove obsolete version check for BR
* Tue Apr 12 2022 Frederic Crozat <fcrozat@suse.com>
- Move bash-completion file out of /etc and do not requires
  bash-completion package.
* Wed Jun 10 2020 Frederic Crozat <fcrozat@suse.com>
- Add the_silver_searcher-2.2.0-portabilityfixes.patch to fix
  build with latest gcc/glibc (gh#ggreer/the_silver_searcher#1377).
* Mon Aug 13 2018 astieger@suse.com
- update to 2.2.0:
  * Add support for Idris, APL, J, D, TLA+, Isabelle, Coq, jinja2,
    PDB, Naccess, thrift, pug, terraform, devicetree, stata
  * Updates support for Haskell
* Wed Sep 27 2017 astieger@suse.com
- update to 2.1.0:
  * Make '-A n -B n' act like '-C n' by printing blank lines
  * Stream decompress zipped files
* Mon Jul 24 2017 astieger@suse.com
- update to 2.0.0:
  * Added file types: Haxe (hx), JSP tag and fragment files
  * No longer read from .agignore, .ignore is the canonical file
  * Add --print-all-files options to print all files searched
  * Add support for inverting ignore rules (e.g. !blah.txt)
  * Fix heap buffer overflow when searching an absolute path
    bsc#1050057
  * documentation updates
* Wed May 24 2017 astieger@suse.com
- update to 1.0.3:
  * add log, elm, twig file types
  * *.js now ignores *.min.js, add .es6 to js file type
* Mon Dec  5 2016 astieger@suse.com
- update to 1.0.2:
  * updated for platforms other than Linux
* Mon Nov 28 2016 astieger@suse.com
- update to 1.0.1:
  * faster substring search
  * fix context line printing when reading from a pipe
  * ignore local-domain socket just like named pipes
  * updates of common file extensions
  * add zsh completion function
* Thu Sep 29 2016 astieger@suse.com
- update to 0.33.0:
  * Fix --word-regexp not applying to alternates
  * The preferred ignore file is .ignore, .agignore is deprecated
* Wed May 18 2016 idonmez@suse.com
- Update to version 0.32.0
  * Add support for Fish, Chapel, Factor, Kotlin, Julia, TypeScript,
    RDoc, Velocity, RestructuredText, TOML, BitBake, Bro file types.
  * Various bugfixes.
* Sat Sep 19 2015 fcrozat@suse.com
- Update to version 0.31.0:
  * Improve bash completion.
  * Add support for Elixir, Mako, Racket and Standard ML file types.
  * various bugfixes.
* Fri May 15 2015 astieger@suse.com
- update to version 0.30.0:
  * --one-device option
  * language types and filter updates
  * performance improvements
  * bug fixes
- use bootstrapped upstream release tarballs, do not re-bootstrap
- add source signature and signing key
- update bash completion location
* Mon Jan 12 2015 multyrealm@gmail.com
- Update to version 0.28.0
* Fri Jan 31 2014 fcrozat@suse.com
- Update to version 0.19.2:
  + Improve output
- Changes from 0.19.1:
  + Don't print two slashes at the start of a path
- Changes from 0.19.0:
- Changes from 0.18.1:
  + performance fixes
  + fix infinite loop in EOF detection
  + Handle '-i' before '-g' or '-G' properly
  + fix build without lzma
- Switch to .tar.gz as they are generated directly by github.
- Replace %%{_prefix}/data by %%{_datadir} in specfile.
* Mon Nov  4 2013 fcastelli@suse.com
- Update to version 0.18:
  * Fix UTF-8 detection.
  * Add support for LZMA and XZ compressed files.
  * better parse gitignore config.
  * Various bugfixes.
- Cleaned up specfile.
* Tue Apr 23 2013 fcastelli@suse.com
- Fix building on SLE.
* Tue Apr 23 2013 fcastelli@suse.com
- fix spec file: use right group
* Tue Apr 23 2013 fcastelli@suse.com
- packaged version 0.14
